/***************************************************************
 * Name:      wxiscanapp.h
 * Purpose:   Defines Application Class
 * Author:    Daniel Nell (daniel.nell@nellresearch.de)
 * Created:   2008-05-04
 * Copyright: Daniel Nell (www.nellresearch.de)
 * License:   GPL
 **************************************************************/

#ifndef WXISCANAPP_H
#define WXISCANAPP_H

#include <wx/app.h>

//////////////////////////////////////////////////////////
// Predefined classes
//
class wxIScanFrame;


//////////////////////////////////////////////////////////
// Class wxIScanFrame
//
/// \brief The application object.
///
/// ...
class wxIScanApp : public wxApp
{
  public:
    /// Program initialization.
    virtual bool OnInit();

    /// Initialize command line parameter handling.
    virtual void OnInitCmdLine( wxCmdLineParser& oParser );

    /// Handle filenames on the command line.
    virtual bool OnCmdLineParsed( wxCmdLineParser& oParser );

    /// Get the file extension filter for all registered image handlers.
    virtual wxString GetImageFilter();

  private:
    /// \brief Adds image handlers to the image handler list.
    ///
    /// \param poHandler    a pointer to the image handler that
    ///                     shall be added.
    virtual void AddImageHandler( wxImageHandler* poHandler );

  private:
    wxLocale m_oLocale;                 ///< Locale the application is using.
    wxString m_strImageFilter;          ///< Current image file filter.
    wxString m_strImageFilterList;      ///< Image file filter list.
    wxIScanFrame* m_poFrame;            ///< A pointer to the application's main window.
};

DECLARE_APP( wxIScanApp )

#endif // WXISCANAPP_H
